/**
 * OW2 Util
 * Copyright (C) 2008
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: IResourceFetcherFactoryManager.java 4392 2008-12-15 14:05:41Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.plan.fetcher.api;

import org.ow2.util.plan.bindings.deploymentplan.DeploymentPlanFragment;
import org.ow2.util.plan.bindings.exceptions.InvalidDeploymentException;
import org.ow2.util.plan.fetcher.api.exceptions.FetcherFactoryException;
import org.ow2.util.plan.fetcher.api.exceptions.ResourceNotFoundException;

/**
 * Manages a list of ResourceFetcher factories that allows it to
 * find a matching factories for deployments. 
 * @author Mickaël LEDUQUE
 */
public interface IResourceFetcherFactoryManager extends Iterable<IResourceFetcherFactory> {

    /**
     * Returns a local file, usable by the deployer, for the given deployment plan fragment.
     * @param deployment the deployment.
     * @return a local file for the deployment.
     * @throws ResourceNotFoundException if the resource couldn't be found on the repositories.
     * @throws InvalidDeploymentException if deployment is not valid.
     */
    public IResourceFetcher getResourceFetcher(DeploymentPlanFragment deployment) throws ResourceNotFoundException, InvalidDeploymentException, FetcherFactoryException;

    /**
     * Adds a ResourceFetcher factory to the managed factories.
     * @param factory the factory to be added.
     */
    public void addResourceFetcherFactory(IResourceFetcherFactory factory);

    /**
     * Removes a ResourceFetcher factory from the managed factories.
     * @param factory the factory to be removed.
     */
    public void removeResourceFetcherFactory(IResourceFetcherFactory factory);

    /**
     * Finds a ResourceFetcher factory that can be used for the given deployment.
     * @param fragment the deployment fragment.
     * @return the factory.
     */
    public IResourceFetcherFactory findFetcherFactoryForDeployment(DeploymentPlanFragment fragment);


}
